# AccessMySQLConverter
AccessMySQLConverter aims to provide a tool which converts MS Access database files (.mdb, .accdb) into a SQL file (and viceversa in future releases) that can be run, generating It's structure and optionally importing It's data

## Installation
To install it you must have Python 3.x installed and run in the command prompt

**pip install accessmysqlconverter**

## Run it
For executing the program run in the command prompt the following instruction

**python -m accessmysqlconverter.application**
